@@ -1,11 +1,11 @@
 from .TwoSampleHC import hc_vals
-from .TwoSampleHC import two_sample_test
+#from .TwoSampleHC import two_sample_test
 from .TwoSampleHC import two_sample_pvals
 from .TwoSampleHC import binom_test_two_sided_random
 from .TwoSampleHC import binom_test_two_sided
-from .TwoSampleHC import two_sample_test_df
-from .TwoSampleHC import hc_vals_full
-from .TwoSampleHC import poisson_test_random
+#from .TwoSampleHC import two_sample_test_df
+#from .TwoSampleHC import hc_vals_full
+#from .TwoSampleHC import poisson_test_random
 
 __all__ = [
     'hc_vals',
